@@ -21,6 +21,9 @@ from requests import Session
 from requests.models import Response
 from responses import POST, activate, add
 
+from opentelemetry.exporter.otlp.proto.common.metrics_encoder import (
+    encode_metrics,
+)
 from opentelemetry.exporter.otlp.proto.http import Compression
 from opentelemetry.exporter.otlp.proto.http.metric_exporter import (
     DEFAULT_COMPRESSION,
@@ -37,6 +40,7 @@ from opentelemetry.sdk.environment_variables import (
     OTEL_EXPORTER_OTLP_HEADERS,
     OTEL_EXPORTER_OTLP_METRICS_CERTIFICATE,
     OTEL_EXPORTER_OTLP_METRICS_COMPRESSION,
+    OTEL_EXPORTER_OTLP_METRICS_DEFAULT_HISTOGRAM_AGGREGATION,
     OTEL_EXPORTER_OTLP_METRICS_ENDPOINT,
     OTEL_EXPORTER_OTLP_METRICS_HEADERS,
     OTEL_EXPORTER_OTLP_METRICS_TEMPORALITY_PREFERENCE,
@@ -58,6 +62,10 @@ from opentelemetry.sdk.metrics.export import (
     ResourceMetrics,
     ScopeMetrics,
 )
+from opentelemetry.sdk.metrics.view import (
+    ExplicitBucketHistogramAggregation,
+    ExponentialBucketHistogramAggregation,
+)
 from opentelemetry.sdk.resources import Resource
 from opentelemetry.sdk.util.instrumentation import (
     InstrumentationScope as SDKInstrumentationScope,
@@ -281,7 +289,7 @@ class TestOTLPMetricExporter(TestCase):
             MetricExportResult.SUCCESS,
         )
 
-        serialized_data = exporter._translate_data(self.metrics["sum_int"])
+        serialized_data = encode_metrics(self.metrics["sum_int"])
         mock_post.assert_called_once_with(
             url=exporter._endpoint,
             data=serialized_data.SerializeToString(),
@@ -421,3 +429,50 @@ class TestOTLPMetricExporter(TestCase):
                 otlp_metric_exporter._preferred_temporality[ObservableGauge],
                 AggregationTemporality.CUMULATIVE,
             )
+
+    def test_exponential_explicit_bucket_histogram(self):
+
+        self.assertIsInstance(
+            OTLPMetricExporter()._preferred_aggregation[Histogram],
+            ExplicitBucketHistogramAggregation,
+        )
+
+        with patch.dict(
+            environ,
+            {
+                OTEL_EXPORTER_OTLP_METRICS_DEFAULT_HISTOGRAM_AGGREGATION: "base2_exponential_bucket_histogram"
+            },
+        ):
+            self.assertIsInstance(
+                OTLPMetricExporter()._preferred_aggregation[Histogram],
+                ExponentialBucketHistogramAggregation,
+            )
+
+        with patch.dict(
+            environ,
+            {OTEL_EXPORTER_OTLP_METRICS_DEFAULT_HISTOGRAM_AGGREGATION: "abc"},
+        ):
+            with self.assertLogs(level=WARNING) as log:
+                self.assertIsInstance(
+                    OTLPMetricExporter()._preferred_aggregation[Histogram],
+                    ExplicitBucketHistogramAggregation,
+                )
+            self.assertIn(
+                (
+                    "Invalid value for OTEL_EXPORTER_OTLP_METRICS_DEFAULT_"
+                    "HISTOGRAM_AGGREGATION: abc, using explicit bucket "
+                    "histogram aggregation"
+                ),
+                log.output[0],
+            )
+
+        with patch.dict(
+            environ,
+            {
+                OTEL_EXPORTER_OTLP_METRICS_DEFAULT_HISTOGRAM_AGGREGATION: "explicit_bucket_histogram"
+            },
+        ):
+            self.assertIsInstance(
+                OTLPMetricExporter()._preferred_aggregation[Histogram],
+                ExplicitBucketHistogramAggregation,
+            )
